import { cache } from 'react';
export const requestContext = (defaultValue) => {
    const getRef = cache(() => ({ current: defaultValue }));
    const getValue = () => getRef().current;
    const setValue = (value) => {
        getRef().current = value;
    };
    return [getValue, setValue];
};
export const [getIdentity, setIdentity] = requestContext(undefined);
export const [getClient, setClient] = requestContext(undefined);
const [_getSDKKey, _setSDKKey] = requestContext(undefined);
export const getSDKKey = () => {
    const key = _getSDKKey();
    if (!key) {
        throw new Error('SDK Client Key must be set!');
    }
    return key;
};
export const setSDKKey = (key) => {
    if (!key) {
        throw new Error('Missing SDK key! Provide a valid SDK key to DevCycleServersideProvider');
    }
    // attempt to make sure server keys don't leak to the client!
    if ((key === null || key === void 0 ? void 0 : key.length) &&
        !key.startsWith('dvc_client') &&
        !key.startsWith('client')) {
        throw new Error('Must use a client SDK key. This key will be sent to the client!');
    }
    _setSDKKey(key);
};
const [_getInitializedPromise, _setInitializedPromise] = requestContext(undefined);
export const getInitializedPromise = _getInitializedPromise;
export const setInitializedPromise = (promise) => {
    if (_getInitializedPromise()) {
        return;
    }
    _setInitializedPromise(promise);
};
export const [getOptions, setOptions] = requestContext({});
export const cacheStorageError = () => {
    return new Error('React cache API is not working as expected. Please contact DevCycle support.');
};
//# sourceMappingURL=requestContext.js.map