import { getVariableValue } from './getVariableValue';
import { getInitializedPromise, setInitializedPromise } from './requestContext';
import { initialize } from './initialize';
import { getUserAgent } from './userAgent';
import { getAllVariables } from './getAllVariables';
import { getAllFeatures } from './allFeatures';
const ensureSetup = (sdkKey, userGetter, options) => {
    const initializedPromise = getInitializedPromise();
    if (!initializedPromise) {
        const serverDataPromise = initialize(sdkKey, userGetter, options);
        setInitializedPromise(serverDataPromise);
        return { serverDataPromise };
    }
    return { serverDataPromise: initializedPromise };
};
// allow return type inference
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
export const setupDevCycle = (sdkKey, userGetter, options = {}) => {
    const _getVariableValue = async (key, defaultValue) => {
        ensureSetup(sdkKey, userGetter, options);
        return getVariableValue(key, defaultValue);
    };
    const _getAllVariables = async () => {
        ensureSetup(sdkKey, userGetter, options);
        return getAllVariables();
    };
    const _getAllFeatures = async () => {
        ensureSetup(sdkKey, userGetter, options);
        return getAllFeatures();
    };
    const _getClientContext = () => {
        var _a;
        const { serverDataPromise } = ensureSetup(sdkKey, userGetter, options);
        const { enableStreaming, ...otherOptions } = options;
        const { disableAutomaticEventLogging, disableCustomEventLogging, disableRealtimeUpdates, apiProxyURL, eventFlushIntervalMS, flushEventQueueSize, } = otherOptions;
        const clientOptions = {
            disableAutomaticEventLogging,
            disableCustomEventLogging,
            disableRealtimeUpdates,
            apiProxyURL,
            eventFlushIntervalMS,
            flushEventQueueSize,
        };
        return {
            serverDataPromise,
            sdkKey: sdkKey,
            options: clientOptions,
            enableStreaming: (_a = options === null || options === void 0 ? void 0 : options.enableStreaming) !== null && _a !== void 0 ? _a : false,
            userAgent: getUserAgent(),
        };
    };
    return {
        getVariableValue: _getVariableValue,
        getAllVariables: _getAllVariables,
        getAllFeatures: _getAllFeatures,
        getClientContext: _getClientContext,
    };
};
//# sourceMappingURL=setupDevCycle.js.map